registerWith static method
void
registerWith()
Called by the generated plugin registrant at app startup.
Implementation
static void registerWith() {
// FFI-only — nothing to register.
}
Called by the generated plugin registrant at app startup.
static void registerWith() {
// FFI-only — nothing to register.
}