EmbeddingModel class
An embedding model backed by a native handle.
Call close to release the native handle.
Constructors
- EmbeddingModel.cohere(String apiKey, String modelId, {String? baseUrl})
-
Create a Cohere embedding model (e.g. embed-english-v3.0).
factory
- EmbeddingModel.google(String apiKey, String modelId, {String? baseUrl})
-
Create a Google embedding model (e.g. gemini-embedding-001).
factory
- EmbeddingModel.openai(String apiKey, String modelId, {String? baseUrl})
-
Create an OpenAI embedding model (e.g. text-embedding-3-small).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
embed(
String valuesJson, [String? optsJson]) → String -
Generate embeddings for
valuesJson(a JSON array of strings). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited