ImageModel class

An image generation model backed by a native handle.

Call close to release the native handle.

Constructors

ImageModel.google(String apiKey, String modelId, {String? baseUrl})
Create a Google image model (e.g. gemini-2.5-flash-image).
factory
ImageModel.openai(String apiKey, String modelId, {String? baseUrl})
Create an OpenAI image model (e.g. dall-e-3).
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Release the native handle. Safe to call multiple times.
generate(String optsJson) String
Generate images from optsJson (serialized ImageCallOptions).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited