RerankingModel class
A reranking model backed by a native handle.
Call close to release the native handle.
Constructors
- RerankingModel.cohere(String apiKey, String modelId, {String? baseUrl})
-
Create a Cohere reranking model (e.g. rerank-v3.0).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rerank(
String optsJson) → String - Rerank documents against a query.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited