SpeechModel class
A speech (text-to-speech) model backed by a native handle.
Call close to release the native handle.
Constructors
- SpeechModel.openai(String apiKey, String modelId, {String? baseUrl})
-
Create an OpenAI speech (TTS) model.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
generate(
String optsJson) → String -
Generate speech audio from
optsJson(serialized SpeechCallOptions). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited