ChatCompletionChunkChoice class

Annotations
  • @JsonSerializable.new()

Constructors

ChatCompletionChunkChoice({required int index, required ChatCompletionDelta delta, String? finishReason, dynamic logprobs})
ChatCompletionChunkChoice.fromJson(Map<String, dynamic> json)
factory

Properties

delta ChatCompletionDelta
final
finishReason String?
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
logprobs → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited