ChatCompletionMessage class

Annotations
  • @JsonSerializable.new()

Constructors

ChatCompletionMessage({required String role, String? content, String? reasoningContent, List<ChatCompletionToolCall>? toolCalls, List? annotations})
ChatCompletionMessage.fromJson(Map<String, dynamic> json)
factory

Properties

annotations List?
final
content String?
final
hashCode int
The hash code for this object.
no setterinherited
reasoningContent String?
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCalls List<ChatCompletionToolCall>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited