ChatCompletionToolCall class
A tool call in a ChatCompletionMessage.
Wire: {"id","type":"function","function":{"name","arguments"}}. The
type field is JSON "type" (Rust #[serde(rename = "type")]).
- Annotations
-
- @JsonSerializable.new()
Constructors
- ChatCompletionToolCall({required String id, required String toolType, required ChatCompletionFunction function})
-
ChatCompletionToolCall.fromJson(Map<
String, dynamic> json) -
factory
Properties
- function → ChatCompletionFunction
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited