ChatCompletionUsage class

Token usage statistics (shared by streaming and non-streaming).

Annotations
  • @JsonSerializable.new()

Constructors

ChatCompletionUsage({required int promptTokens, required int completionTokens, required int totalTokens, PromptTokensDetails? promptTokensDetails, CompletionTokensDetails? completionTokensDetails})
ChatCompletionUsage.fromJson(Map<String, dynamic> json)
factory

Properties

completionTokens int
final
completionTokensDetails CompletionTokensDetails?
final
hashCode int
The hash code for this object.
no setterinherited
promptTokens int
final
promptTokensDetails PromptTokensDetails?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited