ContentPartFileReference class final

Inheritance

Constructors

ContentPartFileReference({required String mediaType, required Map<String, dynamic> reference, String? filename, Map<String, dynamic>? providerOptions})
const

Properties

filename String?
final
hashCode int
The hash code for this object.
no setterinherited
mediaType String
final
providerOptions Map<String, dynamic>?
final
reference Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ContentPartFileReference