ContentPartToolCall class final

Inheritance

Constructors

ContentPartToolCall({required String toolCallId, required String toolName, required dynamic input, String? thoughtSignature, Map<String, dynamic>? providerOptions})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input → dynamic
final
providerOptions Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thoughtSignature String?
final
toolCallId String
final
toolName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ContentPartToolCall