FinishReason class

Why generation stopped. Mirrors FinishReason.ts.

unified is the kebab-case unified reason ("stop", "length", "content-filter", "tool-calls", "error", "other"); raw is the provider-specific reason string (nullable).

Annotations
  • @JsonSerializable.new()

Constructors

FinishReason({required String unified, String? raw})
FinishReason.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
raw String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unified String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited