FunctionTool class

A function tool definition. Mirrors FunctionTool.ts.

Annotations
  • @JsonSerializable.new()

Constructors

FunctionTool({required String name, String? description, required Map<String, dynamic> inputSchema, bool? strict, Map<String, dynamic>? providerOptions, List<Map<String, dynamic>>? inputExamples})
FunctionTool.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
inputExamples List<Map<String, dynamic>>?
final
inputSchema Map<String, dynamic>
final
name String
final
providerOptions Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strict bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited