GenerateResult class

Constructors

GenerateResult({required List<GenerateContent> content, required FinishReason finishReason, required Usage usage, List<Map<String, dynamic>> warnings = const [], Map<String, dynamic>? providerMetadata, required ResponseMetadata response, Map<String, dynamic>? requestBody, Map<String, dynamic>? responseHeaders})
GenerateResult.fromJson(Map<String, dynamic> json)
factory

Properties

content List<GenerateContent>
final
finishReason FinishReason
final
hashCode int
The hash code for this object.
no setterinherited
providerMetadata Map<String, dynamic>?
final
requestBody Map<String, dynamic>?
final
response ResponseMetadata
final
responseHeaders Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage Usage
final
warnings List<Map<String, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited