GenerateTextOptions class

User-facing options for generate_text / stream_text. Mirrors GenerateTextOptions.ts.

Annotations
  • @JsonSerializable.new()

Constructors

GenerateTextOptions({int? maxOutputTokens, double? temperature, List<String>? stopSequences, double? topP, double? topK, double? presencePenalty, double? frequencyPenalty, Map<String, dynamic>? responseFormat, int? seed, List<Tool>? tools, ToolChoice? toolChoice, Map<String, String>? headers, Map<String, dynamic>? providerOptions, ReasoningEffort? reasoning, String? instructions, Map<String, dynamic>? bodyOverrides, int? maxRetries, TimeoutConfiguration? timeout, bool? includeRawChunks, String? sessionId})
GenerateTextOptions.fromJson(Map<String, dynamic> json)
factory

Properties

bodyOverrides Map<String, dynamic>?
final
frequencyPenalty double?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
includeRawChunks bool?
final
instructions String?
final
maxOutputTokens int?
final
maxRetries int?
final
presencePenalty double?
final
providerOptions Map<String, dynamic>?
final
reasoning ReasoningEffort?
final
responseFormat Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final
sessionId String?
final
stopSequences List<String>?
final
temperature double?
final
timeout TimeoutConfiguration?
final
toolChoice ToolChoice?
final
tools List<Tool>?
final
topK double?
final
topP double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited