StreamPartResponseMetadata class final
Response metadata (id, timestamp, model_id).
- Inheritance
-
- Object
- StreamPart
- StreamPartResponseMetadata
Constructors
- StreamPartResponseMetadata({String? id, String? timestamp, String? modelId})
-
StreamPartResponseMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- modelId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String?
-
final
- type → String
-
The variant tag — the single top-level key on the wire (e.g.
'TextDelta','ToolCall','ToolResult','File','Finish','Error'). Empty only for a malformed part.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Re-encode to the externally-tagged wire shape (
{tag: payload}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited