Tool class

A tool definition: function or provider tool. Mirrors Tool.ts.

Constructors

Tool.fromJson(Map<String, dynamic> json)
factory
Tool.function(FunctionTool fn)
factory
Tool.provider({required String id, required String name, required Map<String, dynamic> args})
factory

Properties

args Map<String, dynamic>?
final
function FunctionTool?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited