ToolCall class
A tool call requested by the model. Mirrors ToolCall.ts.
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> ? -
final
- isDynamic → bool?
-
final
- providerExecuted → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thoughtSignature → String?
-
final
- toolCallId → String
-
final
- toolName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited