ToolChoice class

How the model should choose tools. Mirrors ToolChoice.ts.

Constructors

ToolChoice.fromJson(dynamic json)
factory
ToolChoice.tool(String toolName)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const ToolChoice
none → const ToolChoice
required → const ToolChoice