Files class
A files manager (provider file uploads) backed by a native handle.
Call close to release the native handle.
Constructors
- Files.openai(String apiKey, {String? baseUrl})
-
Create an OpenAI files manager. Files take only an API key (no model ID).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
String dataBase64, String mediaType, [String? optsJson]) → String - Upload a file to the provider.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited