TranscriptionModel class
A transcription (speech-to-text) model backed by a native handle.
Call close to release the native handle.
Constructors
- TranscriptionModel.openai(String apiKey, String modelId, {String? baseUrl})
-
Create an OpenAI transcription (STT) model.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
generate(
String audioBase64, String mediaType, [String? optsJson]) → String - Transcribe audio to text.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited