VideoModel class
A video generation model backed by a native handle.
Call close to release the native handle.
Constructors
- VideoModel.google(String apiKey, String modelId, {String? baseUrl})
-
Create a Google video model (e.g. veo-3.0).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Release the native handle. Safe to call multiple times.
-
generate(
String optsJson) → String -
Generate videos from
optsJson(serialized VideoCallOptions). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited