GenerateContentFile class final
A file generated by the model (e.g. an image or document). The data
field is a FileData tagged union; there is no filename field.
- Inheritance
-
- Object
- GenerateContent
- GenerateContentFile
Constructors
-
GenerateContentFile({required FileData data, required String mediaType, Map<
String, dynamic> ? providerMetadata}) -
GenerateContentFile.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → FileData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaType → String
-
final
-
providerMetadata
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The variant tag — the single top-level key on the wire, e.g.
'Text','ToolCall'. Useful for logging / generic dispatch.no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Re-encode to the externally-tagged wire shape (
{tag: payload}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited