GenerateContentToolResult class final
A tool result from a provider-executed tool (e.g. xAI file_search,
web_search). Emitted alongside the preceding ToolCall.
- Inheritance
-
- Object
- GenerateContent
- GenerateContentToolResult
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDynamic → bool?
-
final
- isError → bool?
-
final
- preliminary → bool?
-
final
-
providerMetadata
→ Map<
String, dynamic> ? -
final
- result → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The variant tag — the single top-level key on the wire, e.g.
'Text','ToolCall'. Useful for logging / generic dispatch.no setteroverride - toolCallId → String
-
final
- toolName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Re-encode to the externally-tagged wire shape (
{tag: payload}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited