GenerateTextResult class

Result of generate_text (user-facing). Mirrors GenerateTextResult.ts.

Annotations
  • @JsonSerializable.new()

Constructors

GenerateTextResult({required String text, required List<ToolCall> toolCalls, required FinishReason finishReason, required Usage usage, List<Map<String, dynamic>> warnings = const [], required GenerateResult raw})
GenerateTextResult.fromJson(Map<String, dynamic> json)
factory

Properties

finishReason FinishReason
final
hashCode int
The hash code for this object.
no setterinherited
raw GenerateResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
toolCalls List<ToolCall>
final
usage Usage
final
warnings List<Map<String, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited