ReasoningEffort enum
Values
- providerDefault → const ReasoningEffort
-
const ReasoningEffort('provider-default') - none → const ReasoningEffort
-
const ReasoningEffort('none') - minimal → const ReasoningEffort
-
const ReasoningEffort('minimal') - low → const ReasoningEffort
-
const ReasoningEffort('low') - medium → const ReasoningEffort
-
const ReasoningEffort('medium') - high → const ReasoningEffort
-
const ReasoningEffort('high') - xhigh → const ReasoningEffort
-
const ReasoningEffort('xhigh')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String value) → ReasoningEffort
Constants
-
values
→ const List<
ReasoningEffort> - A constant List of the values in this enum, in order of their declaration.