StreamPartToolCall class final
A complete tool call (alternative to the start/delta/end flow).
- Inheritance
-
- Object
- StreamPart
- StreamPartToolCall
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → dynamic
-
final
- isDynamic → bool?
-
final
- providerExecuted → bool?
-
final
-
providerMetadata
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thoughtSignature → String?
-
final
- toolCallId → String
-
final
- toolName → String
-
final
- type → String
-
The variant tag — the single top-level key on the wire (e.g.
'TextDelta','ToolCall','ToolResult','File','Finish','Error'). Empty only for a malformed part.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Re-encode to the externally-tagged wire shape (
{tag: payload}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited