Usage class
Token usage statistics. Mirrors Usage.ts.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Usage({required TokenUsage inputTokens, required TokenUsage outputTokens, Map<
String, dynamic> ? raw}) -
Usage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → TokenUsage
-
final
- outputTokens → TokenUsage
-
final
-
raw
→ Map<
String, dynamic> ? -
Raw usage information from the provider (opaque JSON).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited